#
# spec file for package ffmpegthumbnailer
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2014 Mariusz Fik <fisiu@opensuse.org>
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  4
Name:           ffmpegthumbnailer
Version:        2.2.2
Release:        2.15
Summary:        Video thumbnailer that can be used by file managers
License:        GPL-2.0-or-later
URL:            https://github.com/dirkvdb/ffmpegthumbnailer
Source:         https://github.com/dirkvdb/%{name}/releases/download/%{version}/%{name}-%{version}.tar.bz2
#PATCH-FIX-UPSTREAM ffmpegthumbnailer-cmake-updates.patch dirk.vdb@gmail.com -- Update CMakeLists.txt for new cmake version.
Patch0:         ffmpegthumbnailer-cmake-updates.patch
# PATCH-FIX-UPSTREAM badshah400@gmail.com -- Removes use of functionality deprecated in ffmpeg4 and dropped from ffmpeg5, patch taken from upstream commit
Patch1:         https://github.com/dirkvdb/ffmpegthumbnailer/commit/372cd422e57a9a3531eb9a30559d665caecff1ba.patch
# PATCH-FIX-UPSTREAM badshah400@gmail.com -- Constify AVCodec, patch taken from upstream commit
Patch2:         https://github.com/dirkvdb/ffmpegthumbnailer/commit/efb5b618f1c1471c1a7900aed3a59d851ea9a210.patch
BuildRequires:  cmake >= 3.12
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libsndfile-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)

%description
This video thumbnailer can be used to create thumbnails for
video files. The thumbnailer uses ffmpeg to decode frames from the
video files, so supported video formats depend on the configuration
flags of ffmpeg.

The project also includes a C/C++ library that can be used by
developers to generate thumbnails in their projects.

%package -n lib%{name}%{soname}
Summary:        Video thumbnail generator

%description -n lib%{name}%{soname}
Video thumbnailer that can be used by file managers.

This video thumbnailer can be used to create thumbnails for video
files. The thumbnailer uses ffmpeg to decode frames from files.

%package -n lib%{name}-devel
Summary:        Development files for ffmpegthumbnailer
Requires:       libffmpegthumbnailer%{soname} = %{version}

%description -n lib%{name}-devel
Video thumbnailer that can be used by file managers.

This video thumbnailer can be used to create thumbnails for video
files. The thumbnailer uses ffmpeg to decode frames from files.

%prep
%autosetup -p1
chmod 644 AUTHORS README

%build
%cmake \
  -DCMAKE_BUILD_TYPE=Release \
  -DENABLE_GIO=ON \
  -DENABLE_THUMBNAILER=ON
%cmake_build

%install
%cmake_install

%post -n lib%{name}%{soname} -p /sbin/ldconfig
%postun -n lib%{name}%{soname} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_mandir}/man1/*.1%{?ext_man}
%{_bindir}/%{name}
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}.thumbnailer

%files -n lib%{name}%{soname}
%{_libdir}/lib%{name}.so.%{soname}
%{_libdir}/lib%{name}.so.%{soname}.*

%files -n lib%{name}-devel
%{_libdir}/lib%{name}.so
%dir %{_includedir}/lib%{name}
%{_includedir}/lib%{name}/*.h
%{_libdir}/pkgconfig/lib%{name}.pc

%changelog
* Mon Aug  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add patches from upstream git to remove references to deprecated
  functions in ffmpeg4 and fix building against ffmpeg5:
  * 372cd422e57a9a3531eb9a30559d665caecff1ba.patch
  * efb5b618f1c1471c1a7900aed3a59d851ea9a210.patch
* Tue Mar  3 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix cmake call
* Mon Mar  2 2020 Martin Pluskal <mpluskal@suse.com>
- Use correct url for sources
- Use modern cmake macro for building
* Sun Mar  1 2020 malcolmlewis@opensuse.org
- Updated to version 2.2.2:
  * Requires cmake >= 3.12.
  * Removed unstable continuous thumbnail creation.
- Add ffmpegthumbnailer-cmake-updates.patch: Update CMakeLists.txt
  for new cmake version.
- Changes from version 2.2.1:
  * CMake improvements: required CMake version is now 3.5 or newer.
  * Fix anamorphic height.
  * Fix libffmpegthumbnailer.pc to work with multilib systems.
  * Fix rotation of 180° rotated videos.
  * Fix prefer_embedded_metadata in c api.
  * Fix crash when setting a log callback using the c api.
  * Check for https as well when skipping stat call.
  * Support specifying the size as string using the c api.
  * Support raw rgb data as image type.
  * Print warnings on stderr instead of stdout.
  * Support for continuous thumbnail creation.
* Fri May 26 2017 jengelh@inai.de
- Trim filler wording from description.
* Tue Nov 29 2016 fisiu@opensuse.org
- Update to 2.2.0, changes since 2.0.9 includes:
  * Option to prefer embedded image metadata over video content
  * Fixed 'Resource temporarily unavailable' errors when using ffmpeg < 3.0
  * Take rotation metadata into account when generating thumbnails
  * Additional video mime types added to the thumbnailer file
  * Add MPEG-TS (MTS) support
  * Project is hosted on github now
  * Use cmake instead of autotools
  * Many other fixes and minor improvements
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Fri Nov 21 2014 fisiu@opensuse.org
- Update to 2.0.9:
  * Fixed gio library loading
  * Support udp sources
  * No longer support older ffmpeg versions
- Drop ffmpegthumbnailer-glibc.patch: fixed upstream.
* Thu Nov 20 2014 joerg.lorenzen@ki.tng.de
- enable thumbnailer support (--enable-thumbnailer)
* Sat Nov  2 2013 joerg.lorenzen@ki.tng.de
- added patch to build against new glibc
* Sat Nov 10 2012 i@margueirte.su
- build against ffmpeg new API.
* Sun Oct 28 2012 pascal.bleser@opensuse.org
- update to 2.0.8
* Mon Oct 17 2011 pascal.bleser@opensuse.org
- update to 2.0.7
* Wed Mar  2 2011 pascal.bleser@opensuse.org
- update to 2.0.6:
  * fixes memory leaks
* Mon Dec 13 2010 pascal.bleser@opensuse.org
- update to 2.0.5:
  * replaced deprecate gnome-vfs with gio (--enable-gio)
* Sun Aug 15 2010 toni@links2linux.de
- update to 2.0.4
- Fixed undefined references when compiling with certain LDFLAGS
- Writing to stdout is now supported
- Support for gnome-vfs uris added. New configure flag (--enable-gnome-vfs),
  this puts a runtime dependancy on libgnome-vfs-2.0
* Tue Jul 20 2010 pascal.bleser@opensuse.org
- update to 2.0.2
* Tue Apr 27 2010 toni@links2linux.de
- update to 2.0.1
  * Setting the thumbnail size to 0 will use the original video size (thanks to John Fremlin)
  * Fix for video files containing lots of audio packets before a video packet
  * Fixed libs in pkgconfig file (thanks to magnus.tuominen)
* Sat Jan  9 2010 toni@links2linux.de
- update to 2.0.0
- new SOname ==> libffmpegthumbnailer4
* Fri Dec 25 2009 toni@links2linux.de
- update to 1.5.6
* Tue Sep 22 2009 Manfred.Tremmel@iiv.de
- update to 1.5.5
* Mon Jun 22 2009 toni@links2linux.de
- update to 1.5.4
* Mon Jun 15 2009 toni@links2linux.de
- update to 1.5.3
* Sun May 24 2009 toni@links2linux.de
- update to 1.5.2
- new SO-Name ==> libffmpegthumbnailer3
* Fri May 15 2009 toni@links2linux.de
- initial package 1.5.1
